@@ -1,6 +1,6 @@
 #! python3
 import click
-from cli.commands import projects, model, api
+from cli.commands import projects, model
 
 @click.group(
     "sieve",
